==> ejc-bfyjerp-impl-3.0.0-20241111.061220-25-sources.jar: com/ejianc/business/project/controller/LeaveSiteController.java <==
package com.ejianc.business.project.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.project.LeaveSiteVO;
import com.ejianc.business.project.bean.InSiteEntity;
import com.ejianc.business.project.bean.LeaveSiteEntity;
import com.ejianc.business.project.service.IInSiteService;
import com.ejianc.business.project.service.ILeaveSiteService;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import com.ejianc.support.idworker.util.IdWorker;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;



/**
 * 项目基本信息管理-人员撤场
 *
 * @author generator
 *
 */
@RestController
@RequestMapping("leaveSite")
public class LeaveSiteController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "BID_PERSON_LEAVE_SITE";

    @Autowired
    private ILeaveSiteService service;

    @Autowired
    private SessionManager sessionManager;

    @Autowired
    private IInSiteService inSiteService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    public CommonResponse<LeaveSiteVO> saveOrUpdate(@RequestBody LeaveSiteVO saveOrUpdateVO) {
    	LeaveSiteEntity entity = BeanMapper.map(saveOrUpdateVO, LeaveSiteEntity.class);
        InSiteEntity personInSite = inSiteService.selectById(saveOrUpdateVO.getOnSiteId());
        if(null != personInSite.getRefBillId() && !personInSite.getRefBillId().equals(saveOrUpdateVO.getId())) {
            return CommonResponse.error("操作失败，当前人员派遣单已被撤场单引用！");
        }
        LeaveSiteEntity dbEntity = null;
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }

            entity.setEmployeeId(Long.valueOf(InvocationInfoProxy.getEmployeeId()));
            entity.setEmployeeName(sessionManager.getUserContext().getEmployeeName());

            entity.setId(IdWorker.getId());
            //更新引用id
            inSiteService.updateRefBillId(entity.getOnSiteId(), entity.getId(), false);
        } else {
            dbEntity = service.selectById(entity.getId());
        }
    	if(null != dbEntity && !dbEntity.getOnSiteId().equals(saveOrUpdateVO.getOnSiteId())) {
            //更新引用id
            inSiteService.updateRefBillId(entity.getOnSiteId(), entity.getId(), true);
        }

    	service.saveOrUpdate(entity, false);
    	LeaveSiteVO vo = BeanMapper.map(entity, LeaveSiteVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    public CommonResponse<LeaveSiteVO> queryDetail(Long id) {
    	LeaveSiteEntity entity = service.selectById(id);
    	LeaveSiteVO vo = BeanMapper.map(entity, LeaveSiteVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    public CommonResponse<String> delete(@RequestBody List<LeaveSiteVO> vos) {
        service.removeAllByIds(vos.stream().map(LeaveSiteVO::getId).collect(Collectors.toList()));
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    public CommonResponse<IPage<LeaveSiteVO>> queryList(@RequestBody QueryParam param) {

        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("onSiteEmployeeName");
        fuzzyFields.add("onSitePostName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));


        IPage<LeaveSiteEntity> page = service.queryPage(param,false);
        IPage<LeaveSiteVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), LeaveSiteVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {

        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("onSiteEmployeeName");
        fuzzyFields.add("onSitePostName");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<LeaveSiteEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("LeaveSite-export.xlsx", beans, response);
    }

    /**
     * @param pageNumber
     * @param pageSize
     * @param condition
     * @param searchObject
     * @param searchText
     * @return
     */
    @RequestMapping(value = "/refLeaveSiteData", method = RequestMethod.GET)
    public CommonResponse<IPage<LeaveSiteVO>> refLeaveSiteData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("onSiteEmployeeName");
        fuzzyFields.add("onSitePostName");
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<LeaveSiteEntity> page = service.queryPage(param,false);
        IPage<LeaveSiteVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), LeaveSiteVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> ejc-bfyjerp-impl-3.0.0-20241226.071626-84-sources.jar: com/ejianc/business/project/controller/LeaveSiteController.java <==
package com.ejianc.business.project.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.project.LeaveSiteVO;
import com.ejianc.business.project.bean.InSiteEntity;
import com.ejianc.business.project.bean.LeaveSiteEntity;
import com.ejianc.business.project.bean.ProjectRegisterEntity;
import com.ejianc.business.project.service.IInSiteService;
import com.ejianc.business.project.service.ILeaveSiteService;
import com.ejianc.business.project.service.IProjectRegisterService;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ExcelExport;
import com.ejianc.support.idworker.util.IdWorker;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;
import java.util.*;
import java.util.stream.Collectors;



/**
 * 项目基本信息管理-人员撤场
 *
 * @author generator
 *
 */
@RestController
@RequestMapping("leaveSite")
public class LeaveSiteController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "BID_PERSON_LEAVE_SITE";

    @Autowired
    private ILeaveSiteService service;

    @Autowired
    private SessionManager sessionManager;

    @Autowired
    private IInSiteService inSiteService;

    @Autowired
    private IProjectRegisterService projectRegisterService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    public CommonResponse<LeaveSiteVO> saveOrUpdate(@RequestBody LeaveSiteVO saveOrUpdateVO) {
    	LeaveSiteEntity entity = BeanMapper.map(saveOrUpdateVO, LeaveSiteEntity.class);
        InSiteEntity personInSite = inSiteService.selectById(saveOrUpdateVO.getOnSiteId());
        if(null != personInSite.getRefBillId() && !personInSite.getRefBillId().equals(saveOrUpdateVO.getId())) {
            return CommonResponse.error("操作失败，当前人员派遣单已被撤场单引用！");
        }
        LeaveSiteEntity dbEntity = null;
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }

            entity.setEmployeeId(Long.valueOf(InvocationInfoProxy.getEmployeeId()));
            entity.setEmployeeName(sessionManager.getUserContext().getEmployeeName());

            entity.setId(IdWorker.getId());
            //更新引用id
            inSiteService.updateRefBillId(entity.getOnSiteId(), entity.getId(), false);
        } else {
            dbEntity = service.selectById(entity.getId());
        }
    	if(null != dbEntity && !dbEntity.getOnSiteId().equals(saveOrUpdateVO.getOnSiteId())) {
            //更新引用id
            inSiteService.updateRefBillId(entity.getOnSiteId(), entity.getId(), true);
        }

    	service.saveOrUpdate(entity, false);
    	LeaveSiteVO vo = BeanMapper.map(entity, LeaveSiteVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    public CommonResponse<LeaveSiteVO> queryDetail(Long id) {
    	LeaveSiteEntity entity = service.selectById(id);
    	LeaveSiteVO vo = BeanMapper.map(entity, LeaveSiteVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    public CommonResponse<String> delete(@RequestBody List<LeaveSiteVO> vos) {
        service.removeAllByIds(vos.stream().map(LeaveSiteVO::getId).collect(Collectors.toList()));
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    public CommonResponse<IPage<LeaveSiteVO>> queryList(@RequestBody QueryParam param) {

        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("onSiteEmployeeName");
        fuzzyFields.add("onSitePostName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        //组织过滤
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            param.getParams().put("parentOrgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        }

        if(param.getParams().containsKey("projectStatus")) {
            //根据项目状态进行过滤
            List<ProjectRegisterEntity> projectList = null;
            if(CollectionUtils.isNotEmpty(commonOrgIds)) {
                projectList = projectRegisterService.getAllByOrgIds(commonOrgIds, param.getParams().get("projectStatus").toString());
            } else if(CollectionUtils.isNotEmpty(departmentIds)) {
                projectList = projectRegisterService.getAllByDepartmentIds(departmentIds, param.getParams().get("projectStatus").toString());
            }
            if(CollectionUtils.isEmpty(projectList)) {
                param.getParams().put("projectId", new Parameter(QueryParam.EQ, -1L));
            } else {
                param.getParams().put("projectId", new Parameter(QueryParam.IN, projectList.stream().map(ProjectRegisterEntity::getId).collect(Collectors.toList())));
            }
            param.getParams().remove("projectStatus");
        }

        IPage<LeaveSiteEntity> page = service.queryPage(param,false);
        IPage<LeaveSiteVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), LeaveSiteVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {

        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("onSiteEmployeeName");
        fuzzyFields.add("onSitePostName");
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);

        CommonResponse<List<OrgVO>> orgVOsResp = iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId());
        List<OrgVO> orgVOS = orgVOsResp.getData();
        List<Long> orgIds = new ArrayList<>();
        if(CollectionUtils.isNotEmpty(orgVOS)) {
            orgIds.addAll(orgVOS.stream().map(OrgVO::getId).collect(Collectors.toList()));
        } else {
            orgIds.add(-1L);
        }
        param.getParams().put("orgId",new Parameter(QueryParam.IN, orgIds));

        if(param.getParams().containsKey("projectStatus")) {
            //根据项目状态进行过滤
            List<ProjectRegisterEntity> projectList = projectRegisterService.getAllByOrgIds(orgIds, param.getParams().get("projectStatus").toString());
            if(CollectionUtils.isEmpty(projectList)) {
                param.getParams().put("projectId", new Parameter(QueryParam.EQ, -1L));
            } else {
                param.getParams().put("projectId", new Parameter(QueryParam.IN, projectList.stream().map(ProjectRegisterEntity::getId).collect(Collectors.toList())));
            }
            param.getParams().remove("projectStatus");
        }

        List<LeaveSiteEntity> list = service.queryList(param);
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("LeaveSite-export.xlsx", beans, response);
    }

    /**
     * @param pageNumber
     * @param pageSize
     * @param condition
     * @param searchObject
     * @param searchText
     * @return
     */
    @RequestMapping(value = "/refLeaveSiteData", method = RequestMethod.GET)
    public CommonResponse<IPage<LeaveSiteVO>> refLeaveSiteData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("billCode");
        fuzzyFields.add("projectCode");
        fuzzyFields.add("projectName");
        fuzzyFields.add("onSiteEmployeeName");
        fuzzyFields.add("onSitePostName");
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<LeaveSiteEntity> page = service.queryPage(param,false);
        IPage<LeaveSiteVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), LeaveSiteVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}
